==> react-components-10.0.0.tgz: package/src/checkbox/tests/chromatic/createTestSuite.jsx <==
import { CommunicationIcon } from "@react-components/icons";
import { Count } from "@react-components/count";
import { Label } from "@react-components/label";
import { cloneElement } from "react";

function Checkbox({ element, ...rest }) {
    return cloneElement(element, rest);
}

function Icons({ element, ...rest }) {
    const checkbox = cloneElement(element, rest);

    return (
        <>
            <div className="flex items-end mb8">
                <Checkbox icons={<CommunicationIcon />} size="small" element={checkbox} className="mr5" />
                <Checkbox icons={<CommunicationIcon />} element={checkbox} className="mr5" />
                <Checkbox icons={<CommunicationIcon />} size="large" element={checkbox} />
            </div>
            <div className="flex items-end mb8">
                <Checkbox icons={[<CommunicationIcon />, <CommunicationIcon />]} size="small" element={checkbox} className="mr5" />
                <Checkbox icons={[<CommunicationIcon />, <CommunicationIcon />]} element={checkbox} className="mr5" />
                <Checkbox icons={[<CommunicationIcon />, <CommunicationIcon />]} size="large" element={checkbox} />
            </div>
            <div className="flex items-end mb8">
                <Checkbox active icons={<CommunicationIcon />} element={checkbox} className="mr5" />
                <Checkbox focus icons={<CommunicationIcon />} element={checkbox} className="mr5" />
                <Checkbox hover icons={<CommunicationIcon />} element={checkbox} className="mr5" />
                <Checkbox focus hover icons={<CommunicationIcon />} element={checkbox} className="mr5" />
                <Checkbox readOnly icons={<CommunicationIcon />} element={checkbox} className="mr5" />
                <Checkbox disabled icons={<CommunicationIcon />} element={checkbox} className="mr5" />
            </div>
            <div className="flex items-end mb8">
                <Checkbox label={<Label>6</Label>} icons={<CommunicationIcon />} size="small" element={checkbox} className="mr5" />
                <Checkbox label={<Label>6</Label>} icons={<CommunicationIcon />} element={checkbox} className="mr5" />
                <Checkbox label={<Label>6</Label>} icons={<CommunicationIcon />} size="large" element={checkbox} />
            </div>
            <div className="flex items-end mb8">
                <Checkbox count={<Count>6</Count>} icons={<CommunicationIcon />} size="small" element={checkbox} className="mr5" />
                <Checkbox count={<Count>6</Count>} icons={<CommunicationIcon />} element={checkbox} className="mr5" />
                <Checkbox count={<Count>6</Count>} icons={<CommunicationIcon />} size="large" element={checkbox} />
            </div>
        </>
    );
}

function Labels({ element, ...rest }) {
    const checkbox = cloneElement(element, rest);

    return (
        <>
            <div className="flex items-end mb8">
                <Checkbox label={<Label>6</Label>} size="small" element={checkbox} className="mr5" />
                <Checkbox label={<Label>6</Label>} element={checkbox} className="mr5" />
                <Checkbox label={<Label>6</Label>} size="large" element={checkbox} />
            </div>
            <div className="flex mb8">
                <Checkbox active label={<Label>6</Label>} element={checkbox} className="mr5" />
                <Checkbox focus label={<Label>6</Label>} element={checkbox} className="mr5" />
                <Checkbox hover label={<Label>6</Label>} element={checkbox} className="mr5" />
                <Checkbox focus hover label={<Label>6</Label>} element={checkbox} className="mr5" />
                <Checkbox disabled label={<Label>6</Label>} element={checkbox} className="mr5" />
                <Checkbox readOnly label={<Label>6</Label>} element={checkbox} />
            </div>
        </>
    );
}

function Counts({ element, ...rest }) {
    const checkbox = cloneElement(element, rest);

    return (
        <>
            <div className="flex items-end mb8">
                <Checkbox count={<Count>6</Count>} size="small" element={checkbox} className="mr5" />
                <Checkbox count={<Count>6</Count>} element={checkbox} className="mr5" />
                <Checkbox count={<Count>6</Count>} size="large" element={checkbox} />
            </div>
            <div className="flex mb8">
                <Checkbox active count={<Count>6</Count>} element={checkbox} className="mr5" />
                <Checkbox focus count={<Count>6</Count>} element={checkbox} className="mr5" />
                <Checkbox hover count={<Count>6</Count>} element={checkbox} className="mr5" />
                <Checkbox focus hover count={<Count>6</Count>} element={checkbox} className="mr5" />
                <Checkbox disabled count={<Count>6</Count>} element={checkbox} className="mr5" />
                <Checkbox readOnly count={<Count>6</Count>} element={checkbox} />
            </div>
        </>
    );
}

export function createTestSuite(checkbox, stories) {
    return stories
        .add("text", () =>
            <div className="flex flex-column">
                <div className="flex items-end mb8">
                    <Checkbox text="Milky Way" element={checkbox} className="mr5" />
                    <Checkbox active text="Milky Way" element={checkbox} className="mr5" />
                    <Checkbox focus text="Milky Way" element={checkbox} className="mr5" />
                    <Checkbox hover text="Milky Way" element={checkbox} className="mr5" />
                    <Checkbox focus hover text="Milky Way" element={checkbox} className="mr5" />
                    <Checkbox disabled text="Milky Way" element={checkbox} className="mr5" />
                    <Checkbox readOnly text="Milky Way" element={checkbox} />
                </div>
                <div className="flex items-end mb8">
                    <Checkbox size="small" text="Milky Way" element={checkbox} className="mr5" />
                    <Checkbox text="Milky Way" element={checkbox} className="mr5" />
                    <Checkbox size="large" text="Milky Way" element={checkbox} />
                </div>
                <Icons text="Milky Way" element={checkbox} />
                <Labels text="Milky Way" element={checkbox} />
                <Counts text="Milky Way" element={checkbox} />
            </div>
        )
        .add("no text", () =>
            <div className="flex flex-column">
                <div className="flex items-end mb8">
                    <Checkbox element={checkbox} className="mr5" />
                    <Checkbox active element={checkbox} className="mr5" />
                    <Checkbox focus element={checkbox} className="mr5" />
                    <Checkbox hover element={checkbox} className="mr5" />
                    <Checkbox focus hover element={checkbox} className="mr5" />
                    <Checkbox disabled element={checkbox} className="mr5" />
                    <Checkbox readOnly element={checkbox} />
                </div>
                <div className="flex items-end mb8">
                    <Checkbox size="small" element={checkbox} className="mr5" />
                    <Checkbox element={checkbox} className="mr5" />
                    <Checkbox size="large" element={checkbox} />
                </div>
                <Icons element={checkbox} />
                <Labels element={checkbox} />
                <Counts element={checkbox} />
            </div>
        )
        .add("overflow", () =>
            <div className="flex mb8">
                <div className="flex items-end mw5">
                    <Checkbox text="PA-99-N2 event and possible exoplanet in galaxy" element={checkbox} className="mr5" />
                </div>
                <div className="flex items-end mw5">
                    <Checkbox icons={[<CommunicationIcon />, <CommunicationIcon />]} text="PA-99-N2 event and possible exoplanet in galaxy" element={checkbox} className="mr5" />
                </div>
                <div className="flex items-end mw5">
                    <Checkbox count={<Count>6</Count>} text="PA-99-N2 event and possible exoplanet in galaxy" element={checkbox} className="mr5" />
                </div>
                <div className="flex items-end mw5">
                    <Checkbox label={<Label>6</Label>} text="PA-99-N2 event and possible exoplanet in galaxy" element={checkbox} className="mr5" />
                </div>
            </div>
        );
}

==> react-components-11.0.0.tgz: package/src/checkbox/tests/chromatic/createTestSuite.jsx <==
import { Count } from "@react-components/count";
import { EmailIcon } from "@react-components/icons";
import { Label } from "@react-components/label";
import { cloneElement } from "react";

function Checkbox({ element, ...rest }) {
    return cloneElement(element, rest);
}

function Icons({ element, ...rest }) {
    const checkbox = cloneElement(element, rest);

    return (
        <>
            <div className="flex items-end mb8">
                <Checkbox icons={<EmailIcon />} size="small" element={checkbox} className="mr5" />
                <Checkbox icons={<EmailIcon />} element={checkbox} className="mr5" />
                <Checkbox icons={<EmailIcon />} size="large" element={checkbox} />
            </div>
            <div className="flex items-end mb8">
                <Checkbox icons={[<EmailIcon />, <EmailIcon />]} size="small" element={checkbox} className="mr5" />
                <Checkbox icons={[<EmailIcon />, <EmailIcon />]} element={checkbox} className="mr5" />
                <Checkbox icons={[<EmailIcon />, <EmailIcon />]} size="large" element={checkbox} />
            </div>
            <div className="flex items-end mb8">
                <Checkbox active icons={<EmailIcon />} element={checkbox} className="mr5" />
                <Checkbox focus icons={<EmailIcon />} element={checkbox} className="mr5" />
                <Checkbox hover icons={<EmailIcon />} element={checkbox} className="mr5" />
                <Checkbox focus hover icons={<EmailIcon />} element={checkbox} className="mr5" />
                <Checkbox readOnly icons={<EmailIcon />} element={checkbox} className="mr5" />
                <Checkbox disabled icons={<EmailIcon />} element={checkbox} className="mr5" />
            </div>
            <div className="flex items-end mb8">
                <Checkbox label={<Label>6</Label>} icons={<EmailIcon />} size="small" element={checkbox} className="mr5" />
                <Checkbox label={<Label>6</Label>} icons={<EmailIcon />} element={checkbox} className="mr5" />
                <Checkbox label={<Label>6</Label>} icons={<EmailIcon />} size="large" element={checkbox} />
            </div>
            <div className="flex items-end mb8">
                <Checkbox count={<Count>6</Count>} icons={<EmailIcon />} size="small" element={checkbox} className="mr5" />
                <Checkbox count={<Count>6</Count>} icons={<EmailIcon />} element={checkbox} className="mr5" />
                <Checkbox count={<Count>6</Count>} icons={<EmailIcon />} size="large" element={checkbox} />
            </div>
        </>
    );
}

function Labels({ element, ...rest }) {
    const checkbox = cloneElement(element, rest);

    return (
        <>
            <div className="flex items-end mb8">
                <Checkbox label={<Label>6</Label>} size="small" element={checkbox} className="mr5" />
                <Checkbox label={<Label>6</Label>} element={checkbox} className="mr5" />
                <Checkbox label={<Label>6</Label>} size="large" element={checkbox} />
            </div>
            <div className="flex mb8">
                <Checkbox active label={<Label>6</Label>} element={checkbox} className="mr5" />
                <Checkbox focus label={<Label>6</Label>} element={checkbox} className="mr5" />
                <Checkbox hover label={<Label>6</Label>} element={checkbox} className="mr5" />
                <Checkbox focus hover label={<Label>6</Label>} element={checkbox} className="mr5" />
                <Checkbox disabled label={<Label>6</Label>} element={checkbox} className="mr5" />
                <Checkbox readOnly label={<Label>6</Label>} element={checkbox} />
            </div>
        </>
    );
}

function Counts({ element, ...rest }) {
    const checkbox = cloneElement(element, rest);

    return (
        <>
            <div className="flex items-end mb8">
                <Checkbox count={<Count>6</Count>} size="small" element={checkbox} className="mr5" />
                <Checkbox count={<Count>6</Count>} element={checkbox} className="mr5" />
                <Checkbox count={<Count>6</Count>} size="large" element={checkbox} />
            </div>
            <div className="flex mb8">
                <Checkbox active count={<Count>6</Count>} element={checkbox} className="mr5" />
                <Checkbox focus count={<Count>6</Count>} element={checkbox} className="mr5" />
                <Checkbox hover count={<Count>6</Count>} element={checkbox} className="mr5" />
                <Checkbox focus hover count={<Count>6</Count>} element={checkbox} className="mr5" />
                <Checkbox disabled count={<Count>6</Count>} element={checkbox} className="mr5" />
                <Checkbox readOnly count={<Count>6</Count>} element={checkbox} />
            </div>
        </>
    );
}

export function createTestSuite(checkbox, stories) {
    return stories
        .add("text", () =>
            <div className="flex flex-column">
                <div className="flex items-end mb8">
                    <Checkbox text="Milky Way" element={checkbox} className="mr5" />
                    <Checkbox active text="Milky Way" element={checkbox} className="mr5" />
                    <Checkbox focus text="Milky Way" element={checkbox} className="mr5" />
                    <Checkbox hover text="Milky Way" element={checkbox} className="mr5" />
                    <Checkbox focus hover text="Milky Way" element={checkbox} className="mr5" />
                    <Checkbox disabled text="Milky Way" element={checkbox} className="mr5" />
                    <Checkbox readOnly text="Milky Way" element={checkbox} />
                </div>
                <div className="flex items-end mb8">
                    <Checkbox size="small" text="Milky Way" element={checkbox} className="mr5" />
                    <Checkbox text="Milky Way" element={checkbox} className="mr5" />
                    <Checkbox size="large" text="Milky Way" element={checkbox} />
                </div>
                <Icons text="Milky Way" element={checkbox} />
                <Labels text="Milky Way" element={checkbox} />
                <Counts text="Milky Way" element={checkbox} />
            </div>
        )
        .add("no text", () =>
            <div className="flex flex-column">
                <div className="flex items-end mb8">
                    <Checkbox element={checkbox} className="mr5" />
                    <Checkbox active element={checkbox} className="mr5" />
                    <Checkbox focus element={checkbox} className="mr5" />
                    <Checkbox hover element={checkbox} className="mr5" />
                    <Checkbox focus hover element={checkbox} className="mr5" />
                    <Checkbox disabled element={checkbox} className="mr5" />
                    <Checkbox readOnly element={checkbox} />
                </div>
                <div className="flex items-end mb8">
                    <Checkbox size="small" element={checkbox} className="mr5" />
                    <Checkbox element={checkbox} className="mr5" />
                    <Checkbox size="large" element={checkbox} />
                </div>
                <Icons element={checkbox} />
                <Labels element={checkbox} />
                <Counts element={checkbox} />
            </div>
        )
        .add("overflow", () =>
            <div className="flex mb8">
                <div className="flex items-end mw5">
                    <Checkbox text="PA-99-N2 event and possible exoplanet in galaxy" element={checkbox} className="mr5" />
                </div>
                <div className="flex items-end mw5">
                    <Checkbox icons={[<EmailIcon />, <EmailIcon />]} text="PA-99-N2 event and possible exoplanet in galaxy" element={checkbox} className="mr5" />
                </div>
                <div className="flex items-end mw5">
                    <Checkbox count={<Count>6</Count>} text="PA-99-N2 event and possible exoplanet in galaxy" element={checkbox} className="mr5" />
                </div>
                <div className="flex items-end mw5">
                    <Checkbox label={<Label>6</Label>} text="PA-99-N2 event and possible exoplanet in galaxy" element={checkbox} className="mr5" />
                </div>
            </div>
        );
}
